Index: src/include/device/pci_ids.h
===================================================================
--- src/include/device/pci_ids.h	(revision 5600)
+++ src/include/device/pci_ids.h	(working copy)
@@ -696,6 +696,7 @@
 #define PCI_DEVICE_ID_TI_4410		0xac41
 #define PCI_DEVICE_ID_TI_4451		0xac42
 #define PCI_DEVICE_ID_TI_1420		0xac51
+#define PCI_DEVICE_ID_TI_1520		0xAC55
 
 #define PCI_VENDOR_ID_SONY		0x104d
 #define PCI_DEVICE_ID_SONY_CXD3222	0x8039
@@ -1741,6 +1742,10 @@
 #define PCI_DEVICE_ID_CCD_B00C		0xb00c
 #define PCI_DEVICE_ID_CCD_B100		0xb100
 
+#define PCI_VENDOR_ID_NOKIA		0x13B8	// Nokia Telecommunications oy
+#define PCI_VENDOR_ID_NOKIA_WIRELESS	0x1603	// Nokia Wireless Communications
+#define PCI_VENDOR_ID_NOKIA_HOME	0x1622	// Nokia Home Communications
+
 #define PCI_VENDOR_ID_3WARE		0x13C1
 #define PCI_DEVICE_ID_3WARE_1000	0x1000
 
Index: src/drivers/Kconfig
===================================================================
--- src/drivers/Kconfig	(revision 5600)
+++ src/drivers/Kconfig	(working copy)
@@ -23,3 +23,21 @@
 	help
 	It sets PCI class to IDE compatible native mode, allowing
 	SeaBIOS, FILO etc... to boot from it.
+	
+config DRIVERS_TI
+	bool "Texas Instruments PCMCIA/CardBus controller"
+	default n
+	help
+		Enables the PCI1225, 1420 and 1520 drivers. This driver 
+		(PCI1225) is developed and needed for the NOKIA IP530. 
+
+source src/drivers/ti/Kconfig
+
+config DRIVERS_DEC21143PD
+	bool "21143 PCI/CardBus 10/100 Mb/s Ethernet LAN Controller"
+	default n
+	help
+		Enables the DEC21143PD driver. This driver is developed 
+		and needed for the NOKIA IP530.
+
+source src/drivers/dec/Kconfig
Index: src/drivers/Makefile.inc
===================================================================
--- src/drivers/Makefile.inc	(revision 5600)
+++ src/drivers/Makefile.inc	(working copy)
@@ -1,3 +1,5 @@
 subdirs-y += generic/debug
 subdirs-y += ati/ragexl
 subdirs-y += sil/3114
+subdirs-y += ti/pcmcia-cardbus
+subdirs-y += dec/21143
Index: src/drivers/dec/Kconfig
===================================================================
--- src/drivers/dec/Kconfig	(revision 0)
+++ src/drivers/dec/Kconfig	(revision 0)
@@ -0,0 +1,25 @@
+menu "Dec 21143 PCI/CardBus 10/100-Mb/s Ethernet LAN Controller"
+	depends on DRIVERS_DEC21143PD
+	
+config DEC21143_CACHE_LINE_SIZE 
+	hex "Cache Line Size Register"
+	default 0x00000000
+	help
+		Corrects the 'Cache Line Size Register' to a initial value, 
+		when not sure set value to 0. 
+
+config DEC21143_EXPANSION_ROM_BASE_ADDRESS
+	hex "Expansion ROM Base Address"
+	default 0
+	help
+		Sets the 'Expansion ROM Base Address' for the controller, when
+		not sure set value 0. 
+
+config DEC21143_COMMAND_AND_STATUS_CONFIGURATION
+	hex "Command and Status Configuration"
+	default 0x02800107
+	help
+		Set the 'Command and Status Configuration', when not sure 
+		set 0x02800107 or 0x02800007
+		
+endmenu

Index: src/drivers/dec/21143/21143pd.c
===================================================================
--- src/drivers/dec/21143/21143pd.c	(revision 0)
+++ src/drivers/dec/21143/21143pd.c	(revision 0)
@@ -0,0 +1,57 @@
+/*
+ * This file is part of the coreboot project.
+ *
+ * Copyright (C) 2010 Marc Bertens <mbertens@xs4all.nl>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
+
+#include <device/device.h>
+#include <device/pci_def.h>
+#include <device/pci.h>
+#include <device/pci_ids.h>
+#include <console/console.h>
+
+/**
+ * This driver take the values from Kconfig and load them in the registers
+ */
+static void dec_21143pd_enable( device_t dev )
+{
+	printk( BIOS_DEBUG, "Init of DECchip 21143PD/TD Kconfig style\n");
+	// Command and Status Configuration Register (CFCS–Offset 04H)
+	pci_write_config32( dev, 0x04, CONFIG_DEC21143_COMMAND_AND_STATUS_CONFIGURATION );
+	printk( BIOS_DEBUG, "0x04 = %08x (07 01 80 02)\n", pci_read_config32(dev, 0x04) );
+	// Cache Line Size Register (Offset 0x0C)
+	pci_write_config8( dev, 0x0C, CONFIG_DEC21143_CACHE_LINE_SIZE );
+	printk( BIOS_DEBUG, "0x0c = %08x (00 80 00 00)\n", pci_read_config32(dev, 0x0C) );
+	// Expansion ROM Base Address Register (CBER–Offset 30H)
+	pci_write_config32( dev, 0x30, CONFIG_DEC21143_EXPANSION_ROM_BASE_ADDRESS );
+	printk( BIOS_DEBUG, "0x30 = %08x (0x00000000)\n", pci_read_config32(dev, 0x30) );
+	return;
+}
+
+static struct device_operations dec_21143pd_ops  = {
+        .read_resources   = pci_dev_read_resources,
+        .set_resources    = pci_dev_set_resources,
+        .enable_resources = pci_dev_enable_resources,
+        .init             = dec_21143pd_enable,
+        .scan_bus         = 0,
+};
+
+static const struct pci_driver dec_21143pd_driver __pci_driver = {
+        .ops    = &dec_21143pd_ops,
+        .vendor = PCI_VENDOR_ID_DEC,
+        .device = PCI_DEVICE_ID_DEC_21142,
+};
Index: src/drivers/dec/21143/Makefile.inc
===================================================================
--- src/drivers/dec/21143/Makefile.inc	(revision 0)
+++ src/drivers/dec/21143/Makefile.inc	(revision 0)
@@ -0,0 +1,5 @@
+##
+##	Each chip needs the generic file and a specific file
+##
+driver-$(CONFIG_DRIVERS_DEC21143PD) += 21143pd.o
+

